pub struct URLSearchParams { /* private fields */ }Expand description
The URLSearchParams interface defines utility methods to work with the query string of a URL.
Implementations
Sourceimpl URLSearchParams
impl URLSearchParams
pub const js_iterate: __impl_iterate = __impl_iterate
pub const js_entries: __impl_entries = __impl_entries
pub const js_keys: __impl_keys = __impl_keys
pub const js_values: __impl_values = __impl_values
Sourceimpl URLSearchParams
impl URLSearchParams
Sourcepub fn iterate<'js>(
&self,
ctx: Ctx<'js>,
this: This<Self>,
) -> Result<Object<'js>>
pub fn iterate<'js>( &self, ctx: Ctx<'js>, this: This<Self>, ) -> Result<Object<'js>>
Returns an iterator allowing iteration through all key/value pairs contained in this object in the same order as they appear in the query string.
Sourcepub fn entries<'js>(
&self,
ctx: Ctx<'js>,
this: This<Self>,
) -> Result<Object<'js>>
pub fn entries<'js>( &self, ctx: Ctx<'js>, this: This<Self>, ) -> Result<Object<'js>>
Returns an iterator allowing iteration through all key/value pairs contained in this object in the same order as they appear in the query string.